@@ -1,16 +1,16 @@
 extern crate kqueue_sys;
 extern crate libc;
 
-use kqueue_sys::{kqueue, kevent};
+use kqueue_sys::{kevent, kqueue};
 use libc::{pid_t, timespec, uintptr_t};
 use std::convert::{AsRef, Into};
 use std::default::Default;
 use std::fs::File;
 use std::io::{self, Error, Result};
+use std::os::unix::io::{AsRawFd, IntoRawFd, RawFd};
 use std::path::Path;
 use std::ptr;
 use std::time::Duration;
-use std::os::unix::io::{AsRawFd, IntoRawFd, RawFd};
 
 pub use kqueue_sys::constants::*;
 
@@ -153,11 +153,12 @@ impl Watcher {
         self
     }
 
-    pub fn add_pid(&mut self,
-                   pid: libc::pid_t,
-                   filter: EventFilter,
-                   flags: FilterFlag)
-                   -> Result<()> {
+    pub fn add_pid(
+        &mut self,
+        pid: libc::pid_t,
+        filter: EventFilter,
+        flags: FilterFlag,
+    ) -> Result<()> {
         let watch = Watched {
             filter: filter,
             flags: flags,
@@ -171,17 +172,20 @@ impl Watcher {
         Ok(())
     }
 
-    pub fn add_filename<P: AsRef<Path>>(&mut self,
-                                        filename: P,
-                                        filter: EventFilter,
-                                        flags: FilterFlag)
-                                        -> Result<()> {
-        let file = try!(File::open(filename.as_ref()));
+    pub fn add_filename<P: AsRef<Path>>(
+        &mut self,
+        filename: P,
+        filter: EventFilter,
+        flags: FilterFlag,
+    ) -> Result<()> {
+        let file = File::open(filename.as_ref())?;
         let watch = Watched {
             filter: filter,
             flags: flags,
-            ident: Ident::Filename(file.into_raw_fd(),
-                                   filename.as_ref().to_string_lossy().into_owned()),
+            ident: Ident::Filename(
+                file.into_raw_fd(),
+                filename.as_ref().to_string_lossy().into_owned(),
+            ),
         };
 
         if !self.watched.contains(&watch) {
@@ -221,12 +225,14 @@ impl Watcher {
         });
 
         let ret = unsafe {
-            kevent(self.queue,
-                   kev.as_ptr(),
-                   kev.len() as i32,
-                   ptr::null_mut(),
-                   0,
-                   ptr::null())
+            kevent(
+                self.queue,
+                kev.as_ptr(),
+                kev.len() as i32,
+                ptr::null_mut(),
+                0,
+                ptr::null(),
+            )
         };
 
         match ret {
@@ -236,7 +242,8 @@ impl Watcher {
     }
 
     pub fn remove_pid(&mut self, pid: libc::pid_t, filter: EventFilter) -> Result<()> {
-        let new_watched = self.watched
+        let new_watched = self
+            .watched
             .drain(..)
             .filter(|x| {
                 if let Ident::Pid(iterpid) = x.ident {
@@ -251,12 +258,14 @@ impl Watcher {
         self.delete_kevents(Ident::Pid(pid), filter)
     }
 
-    pub fn remove_filename<P: AsRef<Path>>(&mut self,
-                                           filename: P,
-                                           filter: EventFilter)
-                                           -> Result<()> {
+    pub fn remove_filename<P: AsRef<Path>>(
+        &mut self,
+        filename: P,
+        filter: EventFilter,
+    ) -> Result<()> {
         let mut fd: RawFd = 0;
-        let new_watched = self.watched
+        let new_watched = self
+            .watched
             .drain(..)
             .filter(|x| {
                 if let Ident::Filename(iterfd, ref iterfile) = x.ident {
@@ -277,7 +286,8 @@ impl Watcher {
     }
 
     pub fn remove_fd(&mut self, fd: RawFd, filter: EventFilter) -> Result<()> {
-        let new_watched = self.watched
+        let new_watched = self
+            .watched
             .drain(..)
             .filter(|x| {
                 if let Ident::Fd(iterfd) = x.ident {
@@ -323,12 +333,14 @@ impl Watcher {
         }
 
         let ret = unsafe {
-            kevent(self.queue,
-                   kevs.as_ptr(),
-                   kevs.len() as i32,
-                   ptr::null_mut(),
-                   0,
-                   ptr::null())
+            kevent(
+                self.queue,
+                kevs.as_ptr(),
+                kevs.len() as i32,
+                ptr::null_mut(),
+                0,
+                ptr::null(),
+            )
         };
 
         self.started = true;
@@ -399,20 +411,27 @@ fn get_event(watcher: &Watcher, timeout: Option<Duration>) -> Option<Event> {
         udata: ptr::null_mut(),
     };
 
-    let tspec = match timeout {
-        Some(ts) => {
-            &timespec {
-                tv_sec: ts.as_secs() as i64,
-                tv_nsec: ts.subsec_nanos() as i64,
-            }
+    let ret = if let Some(ts) = timeout {
+        unsafe {
+            kevent(
+                watcher.queue,
+                ptr::null(),
+                0,
+                &mut kev,
+                1,
+                &timespec {
+                    tv_sec: ts.as_secs() as i64,
+                    tv_nsec: ts.subsec_nanos() as i64,
+                },
+            )
         }
-        None => ptr::null(),
+    } else {
+        unsafe { kevent(watcher.queue, ptr::null(), 0, &mut kev, 1, ptr::null()) }
     };
 
-    let ret = unsafe { kevent(watcher.queue, ptr::null(), 0, &mut kev, 1, tspec) };
     match ret {
         -1 => Some(Event::from_error(kev, watcher)),
-        0 => None,  // timeout expired
+        0 => None, // timeout expired
         _ => Some(Event::new(kev, watcher)),
     }
 }
@@ -524,17 +543,21 @@ impl<'a> Iterator for EventIter<'a> {
 
 #[cfg(test)]
 mod tests {
+    use super::{EventData, EventFilter, Ident, Vnode, Watcher, NOTE_WRITE};
     use std::fs;
     use std::io::Write;
-    use super::{Watcher, EventFilter, EventData, NOTE_WRITE, Vnode, Ident};
 
     #[test]
     fn test_new_watcher() {
         let mut watcher = Watcher::new().unwrap();
         let file = fs::File::create("testing.txt").unwrap();
 
-        assert!(watcher.add_file(&file, EventFilter::EVFILT_VNODE, NOTE_WRITE).is_ok(),
-                "add failed");
+        assert!(
+            watcher
+                .add_file(&file, EventFilter::EVFILT_VNODE, NOTE_WRITE)
+                .is_ok(),
+            "add failed"
+        );
         assert!(watcher.watch().is_ok(), "watch failed");
     }
 
@@ -550,8 +573,12 @@ mod tests {
             assert!(fs::File::create(filename).is_ok(), "file creation failed");
         };
 
-        assert!(watcher.add_filename(filename, EventFilter::EVFILT_VNODE, NOTE_WRITE).is_ok(),
-                "add failed");
+        assert!(
+            watcher
+                .add_filename(filename, EventFilter::EVFILT_VNODE, NOTE_WRITE)
+                .is_ok(),
+            "add failed"
+        );
         assert!(watcher.watch().is_ok(), "watch failed");
 
         let mut new_file = match fs::OpenOptions::new().write(true).open(filename) {
@@ -584,8 +611,12 @@ mod tests {
         assert!(file_res.is_ok(), "file creation failed");
         let mut file = file_res.unwrap();
 
-        assert!(watcher.add_file(&file, EventFilter::EVFILT_VNODE, NOTE_WRITE).is_ok(),
-                "add failed");
+        assert!(
+            watcher
+                .add_file(&file, EventFilter::EVFILT_VNODE, NOTE_WRITE)
+                .is_ok(),
+            "add failed"
+        );
         assert!(watcher.watch().is_ok(), "watch failed");
         assert!(file.write_all(b"foo").is_ok(), "write failed");
         let ev = watcher.iter().next().unwrap();
@@ -612,11 +643,19 @@ mod tests {
             assert!(fs::File::create(filename).is_ok(), "file creation failed");
         };
 
-        assert!(watcher.add_filename(filename, EventFilter::EVFILT_VNODE, NOTE_WRITE).is_ok(),
-                "add failed");
+        assert!(
+            watcher
+                .add_filename(filename, EventFilter::EVFILT_VNODE, NOTE_WRITE)
+                .is_ok(),
+            "add failed"
+        );
         assert!(watcher.watch().is_ok(), "watch failed");
-        assert!(watcher.remove_filename(filename, EventFilter::EVFILT_VNODE).is_ok(),
-                "delete failed");
+        assert!(
+            watcher
+                .remove_filename(filename, EventFilter::EVFILT_VNODE)
+                .is_ok(),
+            "delete failed"
+        );
     }
 
     #[test]
@@ -631,10 +670,18 @@ mod tests {
             assert!(fs::File::create(filename).is_ok(), "file creation failed");
         };
 
-        assert!(watcher.add_filename(filename, EventFilter::EVFILT_VNODE, NOTE_WRITE).is_ok(),
-                "add failed");
-        assert!(watcher.add_filename(filename, EventFilter::EVFILT_VNODE, NOTE_WRITE).is_ok(),
-                "second add failed");
+        assert!(
+            watcher
+                .add_filename(filename, EventFilter::EVFILT_VNODE, NOTE_WRITE)
+                .is_ok(),
+            "add failed"
+        );
+        assert!(
+            watcher
+                .add_filename(filename, EventFilter::EVFILT_VNODE, NOTE_WRITE)
+                .is_ok(),
+            "second add failed"
+        );
 
         assert!(watcher.watched.len() == 1);
     }
